@@ -65,7 +65,8 @@ class TheBlockchainAPIResource:
                 request_method.value,
                 url=self.__url + endpoint,
                 params=payload,
-                headers=headers
+                headers=headers,
+                timeout=120
             )
         else:
             r = requests.request(
@@ -73,7 +74,8 @@ class TheBlockchainAPIResource:
                 url=self.__url + endpoint,
                 data=payload,
                 files=files,
-                headers=headers
+                headers=headers,
+                timeout=120
             )
         try:
             json_content = json.loads(r.content)
